@@ -2,7 +2,7 @@ package Dancer::Session::Cookie;
 use strict;
 use warnings;
 # ABSTRACT: Encrypted cookie-based session backend for Dancer
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use base 'Dancer::Session::Abstract';
 
@@ -104,6 +104,12 @@ sub destroy {
 # Copied from Dancer::Session::Abstract::write_session_id and
 # refactored for testing
 hook 'after' => sub {
+    my $response = shift;
+
+    # UGH! Awful hack because Dancer instantiates responses
+    # and headers too many times and locks out new cookies
+    $response->{_built_cookies} = 0;
+
     if ( $SESSION ) {
         my $c = Dancer::Cookie->new($SESSION->_cookie_params);
         Dancer::Cookies->set_cookie_object($c->name => $c);
@@ -166,7 +172,7 @@ Dancer::Session::Cookie - Encrypted cookie-based session backend for Dancer
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
